@@ -259,13 +259,13 @@ public:
   static lldb::ExpressionResults
   Evaluate(ExecutionContext &exe_ctx, const EvaluateExpressionOptions &options,
            llvm::StringRef expr_cstr, llvm::StringRef expr_prefix,
-           lldb::ValueObjectSP &result_valobj_sp, Error &error,
+           lldb::ValueObjectSP &result_valobj_sp, Status &error,
            uint32_t line_offset = 0, std::string *fixed_expression = nullptr,
            lldb::ModuleSP *jit_module_sp_ptr = nullptr);
 
-  static const Error::ValueType kNoResult =
+  static const Status::ValueType kNoResult =
       0x1001; ///< ValueObject::GetError() returns this if there is no result
-              ///from the expression.
+              /// from the expression.
 
   const char *GetFixedText() {
     if (m_fixed_text.empty())
@@ -281,7 +281,7 @@ protected:
             lldb::ExpressionVariableSP &result) = 0;
 
   static lldb::addr_t GetObjectPointer(lldb::StackFrameSP frame_sp,
-                                       ConstString &object_name, Error &err);
+                                       ConstString &object_name, Status &err);
 
   //------------------------------------------------------------------
   /// Populate m_in_cplusplus_method and m_in_objectivec_method based on the
