@@ -19,14 +19,14 @@
 
 // Other libraries and framework includes
 // Project includes
-#include "lldb/Core/Connection.h"
-#include "lldb/Host/IOObject.h"
 #include "lldb/Host/Pipe.h"
 #include "lldb/Host/Predicate.h"
+#include "lldb/Utility/Connection.h"
+#include "lldb/Utility/IOObject.h"
 
 namespace lldb_private {
 
-class Error;
+class Status;
 class Socket;
 class SocketAddress;
 
@@ -53,20 +53,20 @@ public:
 
   bool IsConnected() const override;
 
-  lldb::ConnectionStatus Connect(llvm::StringRef s, Error *error_ptr) override;
+  lldb::ConnectionStatus Connect(llvm::StringRef s, Status *error_ptr) override;
 
-  lldb::ConnectionStatus Disconnect(Error *error_ptr) override;
+  lldb::ConnectionStatus Disconnect(Status *error_ptr) override;
 
   size_t Read(void *dst, size_t dst_len, const Timeout<std::micro> &timeout,
-              lldb::ConnectionStatus &status, Error *error_ptr) override;
+              lldb::ConnectionStatus &status, Status *error_ptr) override;
 
   size_t Write(const void *src, size_t src_len, lldb::ConnectionStatus &status,
-               Error *error_ptr) override;
+               Status *error_ptr) override;
 
   std::string GetURI() override;
 
   lldb::ConnectionStatus BytesAvailable(const Timeout<std::micro> &timeout,
-                                        Error *error_ptr);
+                                        Status *error_ptr);
 
   bool InterruptRead() override;
 
@@ -83,21 +83,21 @@ protected:
   void CloseCommandPipe();
 
   lldb::ConnectionStatus SocketListenAndAccept(llvm::StringRef host_and_port,
-                                               Error *error_ptr);
+                                               Status *error_ptr);
 
   lldb::ConnectionStatus ConnectTCP(llvm::StringRef host_and_port,
-                                    Error *error_ptr);
+                                    Status *error_ptr);
 
-  lldb::ConnectionStatus ConnectUDP(llvm::StringRef args, Error *error_ptr);
+  lldb::ConnectionStatus ConnectUDP(llvm::StringRef args, Status *error_ptr);
 
   lldb::ConnectionStatus NamedSocketConnect(llvm::StringRef socket_name,
-                                            Error *error_ptr);
+                                            Status *error_ptr);
 
   lldb::ConnectionStatus NamedSocketAccept(llvm::StringRef socket_name,
-                                           Error *error_ptr);
+                                           Status *error_ptr);
 
   lldb::ConnectionStatus UnixAbstractSocketConnect(llvm::StringRef socket_name,
-                                                   Error *error_ptr);
+                                                   Status *error_ptr);
 
   lldb::IOObjectSP m_read_sp;
   lldb::IOObjectSP m_write_sp;
