@@ -21,11 +21,11 @@ namespace lldb_private {
 class Platform;
 class ExecutionContext;
 
-class PosixPlatformCommandOptionValidator : public OptionValidator
-{
-    bool IsValid(Platform &platform, const ExecutionContext &target) const override;
-    const char* ShortConditionString() const override;
-    const char* LongConditionString() const override;
+class PosixPlatformCommandOptionValidator : public OptionValidator {
+  bool IsValid(Platform &platform,
+               const ExecutionContext &target) const override;
+  const char *ShortConditionString() const override;
+  const char *LongConditionString() const override;
 };
 
 } // namespace lldb_private
