@@ -12,7 +12,6 @@
 
 // C Includes
 // C++ Includes
-#include <algorithm>
 #include <memory>
 
 // Microsoft Visual C++ currently does not enable std::atomic to work
@@ -24,6 +23,8 @@
 #include <atomic>
 #endif
 
+#include <stddef.h>
+
 // Other libraries and framework includes
 // Project includes
 
