@@ -5,13 +5,14 @@ The evaluating printf(...) after break stop and then up a stack frame.
 from __future__ import print_function
 
 
-
-import os, time
+import os
+import time
 import lldb
 from lldbsuite.test.decorators import *
 from lldbsuite.test.lldbtest import *
 from lldbsuite.test import lldbutil
 
+
 class Radar9531204TestCase(TestBase):
 
     mydir = TestBase.compute_mydir(__file__)
@@ -24,7 +25,8 @@ class Radar9531204TestCase(TestBase):
 
         self.runCmd("file a.out", CURRENT_EXECUTABLE_SET)
 
-        lldbutil.run_break_set_by_symbol (self, 'foo', sym_exact=True, num_expected_locations=1)
+        lldbutil.run_break_set_by_symbol(
+            self, 'foo', sym_exact=True, num_expected_locations=1)
 
         self.runCmd("run", RUN_SUCCEEDED)
 
@@ -35,7 +37,7 @@ class Radar9531204TestCase(TestBase):
 
         # rdar://problem/9531204
         # "Error dematerializing struct" error when evaluating expressions "up" on the stack
-        self.runCmd('up') # frame select -r 1
+        self.runCmd('up')  # frame select -r 1
 
         self.runCmd("frame variable")
 
