@@ -16,6 +16,7 @@ from lldbsuite.test import lldbutil
 class RaiseTestCase(TestBase):
 
     mydir = TestBase.compute_mydir(__file__)
+    NO_DEBUG_INFO_TESTCASE = True
 
     def test_sigstop(self):
         self.build()
@@ -29,6 +30,10 @@ class RaiseTestCase(TestBase):
         self.build()
         self.signal_test('SIGRTMIN', True)
 
+    def test_sigtrap(self):
+        self.build()
+        self.signal_test('SIGTRAP', True)
+
     def launch(self, target, signal):
         # launch the process, do not stop at entry point.
         process = target.LaunchSimple(
