@@ -57,16 +57,12 @@ class StaticVariableTestCase(TestBase):
                 startstr="(int) A::g_points[1].x = 11")
 
     @expectedFailureAll(
-        oslist=lldbplatformutil.getDarwinOSTriples(),
-        bugnumber="<rdar://problem/28706946>")
-    @expectedFailureAll(
-        compiler=[
-            "clang",
-            "gcc"],
+        compiler=["gcc"],
         bugnumber="Compiler emits incomplete debug info")
     @expectedFailureAll(
-        oslist=['freebsd'],
-        bugnumber='llvm.org/pr20550 failing on FreeBSD-11')
+        compiler=["clang"],
+        compiler_version=["<", "3.9"],
+        bugnumber='llvm.org/pr20550')
     @add_test_categories(['pyapi'])
     def test_with_python_api(self):
         """Test Python APIs on file and class static variables."""
@@ -105,11 +101,11 @@ class StaticVariableTestCase(TestBase):
             if name == 'g_points':
                 self.assertTrue(
                     val.GetValueType() == lldb.eValueTypeVariableStatic)
-                self.assertTrue(val.GetNumChildren() == 2)
+                self.assertEqual(val.GetNumChildren(), 2)
             elif name == 'A::g_points':
                 self.assertTrue(
                     val.GetValueType() == lldb.eValueTypeVariableGlobal)
-                self.assertTrue(val.GetNumChildren() == 2)
+                self.assertEqual(val.GetNumChildren(), 2)
                 child1 = val.GetChildAtIndex(1)
                 self.DebugSBValue(child1)
                 child1_x = child1.GetChildAtIndex(0)
