@@ -25,10 +25,10 @@ int main()
     ThingSummer *summer = [ThingSummer alloc];
     struct things_to_sum tts = { 2, 3, 4 };
     int ret = [summer sumThings:tts];
-
     NSRect rect = {{0, 0}, {10, 20}};    
-
-    // Set breakpoint here.
-    return rect.origin.x;
+	// The Objective C V1 runtime won't read types from metadata so we need
+	// NSValue in our debug info to use it in our test.
+	NSValue *v = [NSValue valueWithRect:rect];
+    return rect.origin.x; // Set breakpoint here.
   }
 }
