@@ -56,7 +56,7 @@ class WatchpointIgnoreCountTestCase(TestBase):
 
         # We should be stopped due to the breakpoint.  Get frame #0.
         process = target.GetProcess()
-        self.assertTrue(process.GetState() == lldb.eStateStopped,
+        self.assertEqual(process.GetState(), lldb.eStateStopped,
                         PROCESS_STOPPED)
         thread = lldbutil.get_stopped_thread(
             process, lldb.eStopReasonBreakpoint)
@@ -75,12 +75,12 @@ class WatchpointIgnoreCountTestCase(TestBase):
             self.HideStdout()
 
         # There should be only 1 watchpoint location under the target.
-        self.assertTrue(target.GetNumWatchpoints() == 1)
+        self.assertEqual(target.GetNumWatchpoints(), 1)
         watchpoint = target.GetWatchpointAtIndex(0)
         self.assertTrue(watchpoint.IsEnabled())
-        self.assertTrue(watchpoint.GetIgnoreCount() == 0)
+        self.assertEqual(watchpoint.GetIgnoreCount(), 0)
         watch_id = watchpoint.GetID()
-        self.assertTrue(watch_id != 0)
+        self.assertNotEqual(watch_id, 0)
         print(watchpoint)
 
         # Now immediately set the ignore count to 2.  When we continue, expect the
@@ -90,12 +90,10 @@ class WatchpointIgnoreCountTestCase(TestBase):
         process.Continue()
 
         # At this point, the inferior process should have exited.
-        self.assertTrue(
-            process.GetState() == lldb.eStateExited,
-            PROCESS_EXITED)
+        self.assertEqual(process.GetState(), lldb.eStateExited, PROCESS_EXITED)
 
         # Verify some vital statistics.
         self.assertTrue(watchpoint)
-        self.assertTrue(watchpoint.GetWatchSize() == 4)
-        self.assertTrue(watchpoint.GetHitCount() == 2)
+        self.assertEqual(watchpoint.GetWatchSize(), 4)
+        self.assertEqual(watchpoint.GetHitCount(), 2)
         print(watchpoint)
