@@ -17,6 +17,7 @@
 #include "lldb/Core/Module.h"
 #include "lldb/Core/Value.h"
 #include "lldb/Host/Host.h"
+#include "lldb/Host/OptionParser.h"
 #include "lldb/Interpreter/Args.h"
 #include "lldb/Interpreter/CommandInterpreter.h"
 #include "lldb/Interpreter/CommandReturnObject.h"
@@ -54,10 +55,10 @@ CommandObjectArgs::CommandOptions::CommandOptions(
 
 CommandObjectArgs::CommandOptions::~CommandOptions() = default;
 
-Error CommandObjectArgs::CommandOptions::SetOptionValue(
+Status CommandObjectArgs::CommandOptions::SetOptionValue(
     uint32_t option_idx, llvm::StringRef option_arg,
     ExecutionContext *execution_context) {
-  Error error;
+  Status error;
 
   const int short_option = m_getopt_table[option_idx].val;
   error.SetErrorStringWithFormat("invalid short option character '%c'",
@@ -223,9 +224,9 @@ bool CommandObjectArgs::DoExecute(Args &args, CommandReturnObject &result) {
   result.GetOutputStream().Printf("Arguments : \n");
 
   for (auto entry : llvm::enumerate(args.entries())) {
-    result.GetOutputStream().Printf("%" PRIu64 " (%s): ", (uint64_t)entry.Index,
-                                    entry.Value.c_str());
-    value_list.GetValueAtIndex(entry.Index)->Dump(&result.GetOutputStream());
+    result.GetOutputStream().Printf(
+        "%" PRIu64 " (%s): ", (uint64_t)entry.index(), entry.value().c_str());
+    value_list.GetValueAtIndex(entry.index())->Dump(&result.GetOutputStream());
     result.GetOutputStream().Printf("\n");
   }
 
