@@ -16,18 +16,17 @@
 // Other libraries and framework includes
 // Project includes
 
-#include "lldb/lldb-types.h"
 #include "lldb/Interpreter/CommandObjectMultiword.h"
 #include "lldb/Interpreter/Options.h"
+#include "lldb/lldb-types.h"
 
 namespace lldb_private {
 
-class CommandObjectType : public CommandObjectMultiword
-{
+class CommandObjectType : public CommandObjectMultiword {
 public:
-    CommandObjectType (CommandInterpreter &interpreter);
+  CommandObjectType(CommandInterpreter &interpreter);
 
-    ~CommandObjectType() override;
+  ~CommandObjectType() override;
 };
 
 } // namespace lldb_private
