@@ -13,9 +13,9 @@
 // C++ Includes
 // Other libraries and framework includes
 // Project includes
-#include "lldb/lldb-private.h"
 #include "lldb/Interpreter/CommandInterpreter.h"
 #include "lldb/Interpreter/CommandReturnObject.h"
+#include "lldb/lldb-private.h"
 
 using namespace lldb;
 using namespace lldb_private;
@@ -25,27 +25,18 @@ using namespace lldb_private;
 //-------------------------------------------------------------------------
 
 CommandObjectVersion::CommandObjectVersion(CommandInterpreter &interpreter)
-    : CommandObjectParsed(interpreter, "version", "Show the LLDB debugger version.", "version")
-{
-}
+    : CommandObjectParsed(interpreter, "version",
+                          "Show the LLDB debugger version.", "version") {}
 
-CommandObjectVersion::~CommandObjectVersion ()
-{
-}
+CommandObjectVersion::~CommandObjectVersion() {}
 
-bool
-CommandObjectVersion::DoExecute (Args& args, CommandReturnObject &result)
-{
-    if (args.GetArgumentCount() == 0)
-    {
-        result.AppendMessageWithFormat ("%s\n", lldb_private::GetVersion());
-        result.SetStatus (eReturnStatusSuccessFinishResult);
-    }
-    else
-    {
-        result.AppendError("the version command takes no arguments.");
-        result.SetStatus (eReturnStatusFailed);
-    }
-    return true;
+bool CommandObjectVersion::DoExecute(Args &args, CommandReturnObject &result) {
+  if (args.GetArgumentCount() == 0) {
+    result.AppendMessageWithFormat("%s\n", lldb_private::GetVersion());
+    result.SetStatus(eReturnStatusSuccessFinishResult);
+  } else {
+    result.AppendError("the version command takes no arguments.");
+    result.SetStatus(eReturnStatusFailed);
+  }
+  return true;
 }
-
