@@ -9,20 +9,20 @@
 
 #include "lldb/Host/common/NativeWatchpointList.h"
 
-#include "lldb/Core/Log.h"
+#include "lldb/Utility/Log.h"
 
 using namespace lldb;
 using namespace lldb_private;
 
-Error NativeWatchpointList::Add(addr_t addr, size_t size, uint32_t watch_flags,
-                                bool hardware) {
+Status NativeWatchpointList::Add(addr_t addr, size_t size, uint32_t watch_flags,
+                                 bool hardware) {
   m_watchpoints[addr] = {addr, size, watch_flags, hardware};
-  return Error();
+  return Status();
 }
 
-Error NativeWatchpointList::Remove(addr_t addr) {
+Status NativeWatchpointList::Remove(addr_t addr) {
   m_watchpoints.erase(addr);
-  return Error();
+  return Status();
 }
 
 const NativeWatchpointList::WatchpointMap &
