@@ -8,7 +8,7 @@
 //===----------------------------------------------------------------------===//
 
 #include "lldb/Host/posix/HostThreadPosix.h"
-#include "lldb/Core/Error.h"
+#include "lldb/Utility/Status.h"
 
 #include <errno.h>
 #include <pthread.h>
@@ -23,8 +23,8 @@ HostThreadPosix::HostThreadPosix(lldb::thread_t thread)
 
 HostThreadPosix::~HostThreadPosix() {}
 
-Error HostThreadPosix::Join(lldb::thread_result_t *result) {
-  Error error;
+Status HostThreadPosix::Join(lldb::thread_result_t *result) {
+  Status error;
   if (IsJoinable()) {
     int err = ::pthread_join(m_thread, result);
     error.SetError(err, lldb::eErrorTypePOSIX);
@@ -38,8 +38,8 @@ Error HostThreadPosix::Join(lldb::thread_result_t *result) {
   return error;
 }
 
-Error HostThreadPosix::Cancel() {
-  Error error;
+Status HostThreadPosix::Cancel() {
+  Status error;
   if (IsJoinable()) {
 #ifndef __ANDROID__
 #ifndef __FreeBSD__
@@ -54,8 +54,8 @@ Error HostThreadPosix::Cancel() {
   return error;
 }
 
-Error HostThreadPosix::Detach() {
-  Error error;
+Status HostThreadPosix::Detach() {
+  Status error;
   if (IsJoinable()) {
     int err = ::pthread_detach(m_thread);
     error.SetError(err, eErrorTypePOSIX);
