@@ -14,10 +14,10 @@
 // Other libraries and framework includes
 // Project includes
 #include "lldb/Core/ArchSpec.h"
+#include "lldb/Host/OptionParser.h"
 #include "lldb/Interpreter/CommandInterpreter.h"
 #include "lldb/Target/ExecutionContext.h"
 #include "lldb/Target/Target.h"
-#include "lldb/Utility/Utils.h"
 
 using namespace lldb;
 using namespace lldb_private;
@@ -58,10 +58,10 @@ llvm::ArrayRef<OptionDefinition> OptionGroupFormat::GetDefinitions() {
   return result.take_front(2);
 }
 
-Error OptionGroupFormat::SetOptionValue(uint32_t option_idx,
-                                        llvm::StringRef option_arg,
-                                        ExecutionContext *execution_context) {
-  Error error;
+Status OptionGroupFormat::SetOptionValue(uint32_t option_idx,
+                                         llvm::StringRef option_arg,
+                                         ExecutionContext *execution_context) {
+  Status error;
   const int short_option = g_option_table[option_idx].short_option;
 
   switch (short_option) {
@@ -235,32 +235,36 @@ bool OptionGroupFormat::ParserGDBFormatLetter(
     m_prev_gdb_format = format_letter;
     return true;
 
-  // Size isn't used for printing instructions, so if a size is specified, and
-  // the previous format was
-  // 'i', then we should reset it to the default ('x').  Otherwise we'll
-  // continue to print as instructions,
-  // which isn't expected.
   case 'b':
-    byte_size = 1;
-    LLVM_FALLTHROUGH;
   case 'h':
-    byte_size = 2;
-    LLVM_FALLTHROUGH;
   case 'w':
-    byte_size = 4;
-    LLVM_FALLTHROUGH;
   case 'g':
-    byte_size = 8;
-
-    m_prev_gdb_size = format_letter;
-    if (m_prev_gdb_format == 'i')
-      m_prev_gdb_format = 'x';
-    return true;
+    {
+      // Size isn't used for printing instructions, so if a size is specified, and
+      // the previous format was
+      // 'i', then we should reset it to the default ('x').  Otherwise we'll
+      // continue to print as instructions,
+      // which isn't expected.
+      if (format_letter == 'b')
+          byte_size = 1;
+      else if (format_letter == 'h')
+          byte_size = 2;
+      else if (format_letter == 'w')
+          byte_size = 4;
+      else if (format_letter == 'g')
+          byte_size = 8;
 
+        m_prev_gdb_size = format_letter;
+        if (m_prev_gdb_format == 'i')
+          m_prev_gdb_format = 'x';
+        return true;
+    }
     break;
   default:
     break;
   }
+
+
   return false;
 }
 
