@@ -10,8 +10,8 @@
 
 #include "AppleObjCClassDescriptorV2.h"
 
-#include "lldb/Core/Log.h"
 #include "lldb/Expression/FunctionCaller.h"
+#include "lldb/Utility/Log.h"
 
 using namespace lldb;
 using namespace lldb_private;
@@ -52,7 +52,7 @@ bool ClassDescriptorV2::objc_class_t::Read(Process *process,
                            + ptr_size; // uintptr_t data_NEVER_USE;
 
   DataBufferHeap objc_class_buf(objc_class_size, '\0');
-  Error error;
+  Status error;
 
   process->ReadMemory(addr, objc_class_buf.GetBytes(), objc_class_size, error);
   if (error.Fail()) {
@@ -92,7 +92,7 @@ bool ClassDescriptorV2::class_rw_t::Read(Process *process, lldb::addr_t addr) {
                 + ptr_size;        // Class nextSiblingClass;
 
   DataBufferHeap buffer(size, '\0');
-  Error error;
+  Status error;
 
   process->ReadMemory(addr, buffer.GetBytes(), size, error);
   if (error.Fail()) {
@@ -132,7 +132,7 @@ bool ClassDescriptorV2::class_ro_t::Read(Process *process, lldb::addr_t addr) {
                 + ptr_size;           // const property_list_t *baseProperties;
 
   DataBufferHeap buffer(size, '\0');
-  Error error;
+  Status error;
 
   process->ReadMemory(addr, buffer.GetBytes(), size, error);
   if (error.Fail()) {
@@ -180,7 +180,7 @@ bool ClassDescriptorV2::Read_class_row(
   class_ro.reset();
   class_rw.reset();
 
-  Error error;
+  Status error;
   uint32_t class_row_t_flags = process->ReadUnsignedIntegerFromMemory(
       objc_class.m_data_ptr, sizeof(uint32_t), 0, error);
   if (!error.Success())
@@ -219,7 +219,7 @@ bool ClassDescriptorV2::method_list_t::Read(Process *process,
                 + sizeof(uint32_t); // uint32_t count;
 
   DataBufferHeap buffer(size, '\0');
-  Error error;
+  Status error;
 
   process->ReadMemory(addr, buffer.GetBytes(), size, error);
   if (error.Fail()) {
@@ -242,7 +242,7 @@ bool ClassDescriptorV2::method_t::Read(Process *process, lldb::addr_t addr) {
   size_t size = GetSize(process);
 
   DataBufferHeap buffer(size, '\0');
-  Error error;
+  Status error;
 
   process->ReadMemory(addr, buffer.GetBytes(), size, error);
   if (error.Fail()) {
@@ -276,7 +276,7 @@ bool ClassDescriptorV2::ivar_list_t::Read(Process *process, lldb::addr_t addr) {
                 + sizeof(uint32_t); // uint32_t count;
 
   DataBufferHeap buffer(size, '\0');
-  Error error;
+  Status error;
 
   process->ReadMemory(addr, buffer.GetBytes(), size, error);
   if (error.Fail()) {
@@ -299,7 +299,7 @@ bool ClassDescriptorV2::ivar_t::Read(Process *process, lldb::addr_t addr) {
   size_t size = GetSize(process);
 
   DataBufferHeap buffer(size, '\0');
-  Error error;
+  Status error;
 
   process->ReadMemory(addr, buffer.GetBytes(), size, error);
   if (error.Fail()) {
@@ -501,10 +501,8 @@ void ClassDescriptorV2::iVarsStorage::fill(AppleObjCRuntimeV2 &runtime,
   if (m_filled)
     return;
   std::lock_guard<std::recursive_mutex> guard(m_mutex);
-  Log *log(GetLogIfAllCategoriesSet(LIBLLDB_LOG_TYPES | LIBLLDB_LOG_VERBOSE));
-  if (log)
-    log->Printf("[ClassDescriptorV2::iVarsStorage::fill] class_name = %s",
-                descriptor.GetClassName().AsCString("<unknown"));
+  Log *log(GetLogIfAllCategoriesSet(LIBLLDB_LOG_TYPES));
+  LLDB_LOGV(log, "class_name = {0}", descriptor.GetClassName());
   m_filled = true;
   ObjCLanguageRuntime::EncodingToTypeSP encoding_to_type_sp(
       runtime.GetEncodingToType());
@@ -519,38 +517,29 @@ void ClassDescriptorV2::iVarsStorage::fill(AppleObjCRuntimeV2 &runtime,
                                                        uint64_t size) -> bool {
     const bool for_expression = false;
     const bool stop_loop = false;
-    if (log)
-      log->Printf("[ClassDescriptorV2::iVarsStorage::fill] name = %s, encoding "
-                  "= %s, offset_ptr = %" PRIx64 ", size = %" PRIu64,
-                  name, type, offset_ptr, size);
+    LLDB_LOGV(log, "name = {0}, encoding = {1}, offset_ptr = {2:x}, size = {3}",
+              name, type, offset_ptr, size);
     CompilerType ivar_type =
         encoding_to_type_sp->RealizeType(type, for_expression);
     if (ivar_type) {
-      if (log)
-        log->Printf("[ClassDescriptorV2::iVarsStorage::fill] name = %s, "
-                    "encoding = %s, offset_ptr = %" PRIx64 ", size = %" PRIu64
-                    " , type_size = %" PRIu64,
-                    name, type, offset_ptr, size,
-                    ivar_type.GetByteSize(nullptr));
+      LLDB_LOGV(log,
+                "name = {0}, encoding = {1}, offset_ptr = {2:x}, size = "
+                "{3}, type_size = {4}",
+                name, type, offset_ptr, size, ivar_type.GetByteSize(nullptr));
       Scalar offset_scalar;
-      Error error;
+      Status error;
       const int offset_ptr_size = 4;
       const bool is_signed = false;
       size_t read = process->ReadScalarIntegerFromMemory(
           offset_ptr, offset_ptr_size, is_signed, offset_scalar, error);
       if (error.Success() && 4 == read) {
-        if (log)
-          log->Printf(
-              "[ClassDescriptorV2::iVarsStorage::fill] offset_ptr = %" PRIx64
-              " --> %" PRIu32,
-              offset_ptr, offset_scalar.SInt());
+        LLDB_LOGV(log, "offset_ptr = {0:x} --> {1}", offset_ptr,
+                  offset_scalar.SInt());
         m_ivars.push_back(
             {ConstString(name), ivar_type, size, offset_scalar.SInt()});
-      } else if (log)
-        log->Printf(
-            "[ClassDescriptorV2::iVarsStorage::fill] offset_ptr = %" PRIx64
-            " --> read fail, read = %zu",
-            offset_ptr, read);
+      } else
+        LLDB_LOGV(log, "offset_ptr = {0:x} --> read fail, read = %{1}",
+                  offset_ptr, read);
     }
     return stop_loop;
   });
