@@ -14,45 +14,39 @@
 
 #include "lldb/Symbol/ClangASTImporter.h"
 
-namespace clang
-{
+namespace clang {
 class CharUnits;
 class CXXRecordDecl;
 class FieldDecl;
 class RecordDecl;
 }
 
-namespace lldb_private
-{
+namespace lldb_private {
 class ClangASTContext;
 class CompilerType;
 }
 
-namespace llvm
-{
-namespace pdb
-{
+namespace llvm {
+namespace pdb {
 class PDBSymbol;
 class PDBSymbolData;
 class PDBSymbolTypeBuiltin;
 }
 }
 
-class PDBASTParser
-{
+class PDBASTParser {
 public:
-    PDBASTParser(lldb_private::ClangASTContext &ast);
-    ~PDBASTParser();
+  PDBASTParser(lldb_private::ClangASTContext &ast);
+  ~PDBASTParser();
 
-    lldb::TypeSP
-    CreateLLDBTypeFromPDBType(const llvm::pdb::PDBSymbol &type);
+  lldb::TypeSP CreateLLDBTypeFromPDBType(const llvm::pdb::PDBSymbol &type);
 
 private:
-    bool
-    AddEnumValue(lldb_private::CompilerType enum_type, const llvm::pdb::PDBSymbolData &data) const;
+  bool AddEnumValue(lldb_private::CompilerType enum_type,
+                    const llvm::pdb::PDBSymbolData &data) const;
 
-    lldb_private::ClangASTContext &m_ast;
-    lldb_private::ClangASTImporter m_ast_importer;
+  lldb_private::ClangASTContext &m_ast;
+  lldb_private::ClangASTImporter m_ast_importer;
 };
 
 #endif // SymbolFileDWARF_DWARFASTParserClang_h_
