@@ -88,7 +88,7 @@ kern_return_t MachTask::Suspend() {
   err = ::task_suspend(task);
   if (DNBLogCheckLogBit(LOG_TASK) || err.Fail())
     err.LogThreaded("::task_suspend ( target_task = 0x%4.4x )", task);
-  return err.Error();
+  return err.Status();
 }
 
 //----------------------------------------------------------------------
@@ -113,7 +113,7 @@ kern_return_t MachTask::Resume() {
         err.LogThreaded("::task_resume ( target_task = 0x%4.4x )", task);
     }
   }
-  return err.Error();
+  return err.Status();
 }
 
 //----------------------------------------------------------------------
@@ -531,7 +531,7 @@ task_t MachTask::TaskPortForProcessID(pid_t pid, DNBError &err,
         char str[1024];
         ::snprintf(str, sizeof(str), "::task_for_pid ( target_tport = 0x%4.4x, "
                                      "pid = %d, &task ) => err = 0x%8.8x (%s)",
-                   task_self, pid, err.Error(),
+                   task_self, pid, err.Status(),
                    err.AsString() ? err.AsString() : "success");
         if (err.Fail())
           err.SetErrorString(str);
@@ -583,7 +583,7 @@ kern_return_t MachTask::BasicInfo(task_t task, struct task_basic_info *info) {
                    info->suspend_count, (uint64_t)info->virtual_size,
                    (uint64_t)info->resident_size, user, system);
   }
-  return err.Error();
+  return err.Status();
 }
 
 //----------------------------------------------------------------------
@@ -687,7 +687,7 @@ kern_return_t MachTask::ShutDownExcecptionThread() {
     err.LogThreaded("::mach_port_deallocate ( task = 0x%4.4x, name = 0x%4.4x )",
                     task_self, exception_port);
 
-  return err.Error();
+  return err.Status();
 }
 
 void *MachTask::ExceptionThread(void *arg) {
@@ -805,7 +805,7 @@ void *MachTask::ExceptionThread(void *arg) {
                                       MACH_RCV_MSG | MACH_RCV_INTERRUPT, 0);
     }
 
-    if (err.Error() == MACH_RCV_INTERRUPTED) {
+    if (err.Status() == MACH_RCV_INTERRUPTED) {
       // If we have no task port we should exit this thread
       if (!mach_task->ExceptionPortIsValid()) {
         DNBLogThreadedIf(LOG_EXCEPTIONS, "thread cancelled...");
@@ -824,7 +824,7 @@ void *MachTask::ExceptionThread(void *arg) {
         // Our task has died, exit the thread.
         break;
       }
-    } else if (err.Error() == MACH_RCV_TIMED_OUT) {
+    } else if (err.Status() == MACH_RCV_TIMED_OUT) {
       if (num_exceptions_received > 0) {
         // We were receiving all current exceptions with a timeout of zero
         // it is time to go back to our normal looping mode
@@ -860,7 +860,7 @@ void *MachTask::ExceptionThread(void *arg) {
         }
       }
 #endif
-    } else if (err.Error() != KERN_SUCCESS) {
+    } else if (err.Status() != KERN_SUCCESS) {
       DNBLogThreadedIf(LOG_EXCEPTIONS, "got some other error, do something "
                                        "about it??? nah, continuing for "
                                        "now...");
@@ -947,7 +947,7 @@ nub_addr_t MachTask::AllocateMemory(size_t size, uint32_t permissions) {
 
   DNBError err;
   err = ::mach_vm_allocate(task, &addr, size, TRUE);
-  if (err.Error() == KERN_SUCCESS) {
+  if (err.Status() == KERN_SUCCESS) {
     // Set the protections:
     vm_prot_t mach_prot = VM_PROT_NONE;
     if (permissions & eMemoryPermissionsReadable)
@@ -958,7 +958,7 @@ nub_addr_t MachTask::AllocateMemory(size_t size, uint32_t permissions) {
       mach_prot |= VM_PROT_EXECUTE;
 
     err = ::mach_vm_protect(task, addr, size, 0, mach_prot);
-    if (err.Error() == KERN_SUCCESS) {
+    if (err.Status() == KERN_SUCCESS) {
       m_allocations.insert(std::make_pair(addr, size));
       return addr;
     }
